--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersAnimalCareSeasons by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.7 Compatible with Seasons
-- 30.11.2018 - 21.05.2020

-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
--]]

RealNumbersAnimalCareSeasons = {};

function RealNumbersAnimalCareSeasons:loadMap(name)


	print("\nFS19_RealLifeNumbers: RealNumbersAnimalCareSeasons active\n")

	RNS.notRunYetRealNumbersAnimalCareSeasons = true;
	RNS.upStartRealNumbersAnimalCareSeasons = true;

end;


function RealNumbersAnimalCareSeasons:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersAnimalCareSeasons:update(dt)
	local iFillType = 0;
	local minute = g_currentMission.environment.currentMinute;


	local runMinute = minute % 10; -- remainder
	if runMinute ~= 2 then RNS.notRunYetRealNumbersAnimalCareSeasons = true; end;
	if runMinute == 2 or RNS.upStartRealNumbersAnimalCareSeasons then 
		if RNS.notRunYetRealNumbersAnimalCareSeasons then

--			print("RealNumbersAnimalCareSeasons:update"); -- comment out when not debugging
			
			if g_seasons ~= nil then

-- PIGS

				for k = 1,4 do
					iFillType = RNS.pigs.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.pigs.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.pigs.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.pigs.foodPerDayPerKg[k]/RN.commodityDensity.PIGFOOD;
-- weight
					myAnimalType.seasons.buyWeight = RNS.pigs.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.pigs.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.pigs.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.pigs.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
					myAnimalType.seasons.liquidManure =	RNS.pigs.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
					myAnimalType.seasons.foodSpillage = RNS.pigs.foodSpillage[k];
-- breeding
					myAnimalType.seasons.fertileAge = RNS.pigs.fertileAge[k];
					myAnimalType.seasons.averageLitterSize = RNS.pigs.averageLitterSize[k];
					myAnimalType.seasons.variationLitterSize = RNS.pigs.variationLitterSize[k];
					myAnimalType.seasons.birthRate = RNS.pigs.birthRate[k];
					myAnimalType.seasons.femalePercentage = RNS.pigs.femalePercentage[k];
					
					myAnimalType.breeding.fertileAge = RNS.pigs.fertileAge[k];
					myAnimalType.breeding.averageLitterSize = RNS.pigs.averageLitterSize[k];
					myAnimalType.breeding.variationLitterSize = RNS.pigs.variationLitterSize[k];
					myAnimalType.breeding.birthRate = RNS.pigs.birthRate[k];
					myAnimalType.breeding.femalePercentage = RNS.pigs.femalePercentage[k];

-- store
					myAnimalType.seasons.buyPrice = RNS.pigs.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.pigs.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.pigs.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.pigs.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.pigs.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.pigs.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.pigs.buyIsFemale[k];

					myAnimalType.storeInfo.buyPrice = RNS.pigs.buyPriceMultiplier[k] * RNS.pigs.buyWeight[k] * RNS.pigs.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.pigs.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.pigs.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.pigs.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.pigs.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.pigs.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.pigs.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.pigs.buyWeight[k];

				end;

-- COWS

				for k = 1,4 do
					iFillType = RNS.cows1.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.cows1.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.cows1.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.cows1.foodTroughFraction[k] * RNS.cows1.foodPerDayPerKg[k]/RN.commodityDensity.COWFOOD;
-- weight
					myAnimalType.seasons.buyWeight = RNS.cows1.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.cows1.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.cows1.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.cows1.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
					myAnimalType.seasons.liquidManure =	RNS.cows1.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
					myAnimalType.seasons.foodSpillage = RNS.cows1.foodSpillage[k];
-- breeding
					myAnimalType.seasons.fertileAge = RNS.cows1.fertileAge[k];
					myAnimalType.seasons.averageLitterSize = RNS.cows1.averageLitterSize[k];
					myAnimalType.seasons.variationLitterSize = RNS.cows1.variationLitterSize[k];
					myAnimalType.seasons.birthRate = RNS.cows1.birthRate[k];
					myAnimalType.seasons.femalePercentage = RNS.cows1.femalePercentage[k];
					
					myAnimalType.breeding.fertileAge = RNS.cows1.fertileAge[k];
					myAnimalType.breeding.averageLitterSize = RNS.cows1.averageLitterSize[k];
					myAnimalType.breeding.variationLitterSize = RNS.cows1.variationLitterSize[k];
					myAnimalType.breeding.birthRate = RNS.cows1.birthRate[k];
					myAnimalType.breeding.femalePercentage = RNS.cows1.femalePercentage[k];
-- store
					myAnimalType.seasons.buyPrice = RNS.cows1.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.cows1.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.cows1.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.cows1.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.cows1.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.cows1.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.cows1.buyIsFemale[k];

					myAnimalType.storeInfo.buyPrice = RNS.cows1.buyPriceMultiplier[k] * RNS.cows1.buyWeight[k] * RNS.cows1.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.cows1.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.cows1.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.cows1.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.cows1.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.cows1.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.cows1.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.cows1.buyWeight[k];

				end;

				for k = 1,4 do
					iFillType = RNS.cows2.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.cows2.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.cows2.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.cows2.foodTroughFraction[k] * RNS.cows2.foodPerDayPerKg[k]/RN.commodityDensity.COWFOOD;
-- weight
					myAnimalType.seasons.buyWeight = RNS.cows2.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.cows2.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.cows2.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.cows2.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
					myAnimalType.seasons.liquidManure =	RNS.cows2.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
					myAnimalType.seasons.foodSpillage = RNS.cows2.foodSpillage[k];
-- breeding
					myAnimalType.seasons.fertileAge = RNS.cows2.fertileAge[k];
					myAnimalType.seasons.averageLitterSize = RNS.cows2.averageLitterSize[k];
					myAnimalType.seasons.variationLitterSize = RNS.cows2.variationLitterSize[k];
					myAnimalType.seasons.birthRate = RNS.cows2.birthRate[k];
					myAnimalType.seasons.femalePercentage = RNS.cows2.femalePercentage[k];
					
					myAnimalType.breeding.fertileAge = RNS.cows2.fertileAge[k];
					myAnimalType.breeding.averageLitterSize = RNS.cows2.averageLitterSize[k];
					myAnimalType.breeding.variationLitterSize = RNS.cows2.variationLitterSize[k];
					myAnimalType.breeding.birthRate = RNS.cows2.birthRate[k];
					myAnimalType.breeding.femalePercentage = RNS.cows2.femalePercentage[k];
					
-- store
					myAnimalType.seasons.buyPrice = RNS.cows2.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.cows2.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.cows2.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.cows2.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.cows2.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.cows2.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.cows2.buyIsFemale[k];

					myAnimalType.storeInfo.buyPrice = RNS.cows2.buyPriceMultiplier[k] * RNS.cows2.buyWeight[k] * RNS.cows2.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.cows2.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.cows2.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.cows2.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.cows2.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.cows2.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.cows2.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.cows2.buyWeight[k];

				end;

-- SHEEP

				for k = 1,4 do
					iFillType = RNS.sheep.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.sheep.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.sheep.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.sheep.foodTroughFraction[k] * RNS.sheep.foodPerDayPerKg[k]/RN.commodityDensity.ROUNDBALE_GRASS;
-- weight
					myAnimalType.seasons.buyWeight = RNS.sheep.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.sheep.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.sheep.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.sheep.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
					myAnimalType.seasons.liquidManure =	RNS.sheep.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
					myAnimalType.seasons.foodSpillage = RNS.sheep.foodSpillage[k];
					myAnimalType.seasons.pallets = RNS.sheep.woolKgPerYear[k]/RN.commodityDensity.WOOL; -- L wool per year
-- breeding
					myAnimalType.seasons.fertileAge = RNS.sheep.fertileAge[k];
					myAnimalType.seasons.averageLitterSize = RNS.sheep.averageLitterSize[k];
					myAnimalType.seasons.variationLitterSize = RNS.sheep.variationLitterSize[k];
					myAnimalType.seasons.birthRate = RNS.sheep.birthRate[k];
					myAnimalType.seasons.femalePercentage = RNS.sheep.femalePercentage[k];

					myAnimalType.breeding.fertileAge = RNS.sheep.fertileAge[k];
					myAnimalType.breeding.averageLitterSize = RNS.sheep.averageLitterSize[k];
					myAnimalType.breeding.variationLitterSize = RNS.sheep.variationLitterSize[k];
					myAnimalType.breeding.birthRate = RNS.sheep.birthRate[k];
					myAnimalType.breeding.femalePercentage = RNS.sheep.femalePercentage[k];
					
-- store
					myAnimalType.seasons.buyPrice = RNS.sheep.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.sheep.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.sheep.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.sheep.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.sheep.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.sheep.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.sheep.buyIsFemale[k];

					myAnimalType.storeInfo.buyPrice = RNS.sheep.buyPriceMultiplier[k] * RNS.sheep.buyWeight[k] * RNS.sheep.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.sheep.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.sheep.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.sheep.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.sheep.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.sheep.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.sheep.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.sheep.buyWeight[k];

				end;

-- CHICKEN

				for k = 1,4 do
					iFillType = RNS.chicken.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.chicken.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.chicken.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.chicken.foodPerDayPerKg[k]/RN.commodityDensity.CHICKENFOOD;
-- weight
					myAnimalType.seasons.buyWeight = RNS.chicken.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.chicken.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.chicken.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.chicken.manurePerDayPerKg[k]/RN.commodityDensity.MANURE;
					myAnimalType.seasons.liquidManure =	RNS.chicken.liquidManure[k]/RN.commodityDensity.LIQUIDMANURE;
					myAnimalType.seasons.foodSpillage = RNS.chicken.foodSpillage[k];
					myAnimalType.seasons.pallets = RNS.chicken.eggsPerYear[k] * 0.06/RN.commodityDensity.EGG; -- L egg per year per hen, 1 egg = 60 g
-- breeding
					myAnimalType.seasons.fertileAge = RNS.chicken.fertileAge[k];
					myAnimalType.seasons.averageLitterSize = RNS.chicken.averageLitterSize[k];
					myAnimalType.seasons.variationLitterSize = RNS.chicken.variationLitterSize[k];
					myAnimalType.seasons.birthRate = RNS.chicken.birthRate[k];
					myAnimalType.seasons.femalePercentage = RNS.chicken.femalePercentage[k];
					
					myAnimalType.breeding.fertileAge = RNS.chicken.fertileAge[k];
					myAnimalType.breeding.averageLitterSize = RNS.chicken.averageLitterSize[k];
					myAnimalType.breeding.variationLitterSize = RNS.chicken.variationLitterSize[k];
					myAnimalType.breeding.birthRate = RNS.chicken.birthRate[k];
					myAnimalType.breeding.femalePercentage = RNS.chicken.femalePercentage[k];

-- store
					myAnimalType.seasons.buyPrice = RNS.chicken.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.chicken.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.chicken.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.chicken.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.chicken.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.chicken.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.chicken.buyIsFemale[k];

					myAnimalType.storeInfo.buyPrice = RNS.chicken.buyPriceMultiplier[k] * RNS.chicken.buyWeight[k] * RNS.chicken.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.chicken.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.chicken.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.chicken.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.chicken.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.chicken.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.chicken.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.chicken.buyWeight[k];

				end;

-- HORSES

				for k = 1,4 do
					iFillType = RNS.horses1.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.horses1.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.horses1.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.horses1.foodPerDayPerKg[k];
-- weight
					myAnimalType.seasons.buyWeight = RNS.horses1.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.horses1.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.horses1.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.horses1.manurePerDayPerKg[k];
					myAnimalType.seasons.liquidManure =	RNS.horses1.liquidManure[k];
					myAnimalType.seasons.foodSpillage = RNS.horses1.foodSpillage[k];
-- store
					myAnimalType.seasons.buyPrice = RNS.horses1.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.horses1.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.horses1.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.horses1.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.horses1.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.horses1.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.horses1.buyIsFemale[k];
					myAnimalType.seasons.liveryIncome  = RNS.horses1.liveryIncome[k];
					myAnimalType.seasons.trainingDifficulty = RNS.horses1.trainingDifficulty[k];

					myAnimalType.storeInfo.buyPrice = RNS.horses1.buyPriceMultiplier[k] * RNS.horses1.buyWeight[k] * RNS.horses1.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.horses1.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.horses1.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.horses1.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.horses1.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.horses1.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.horses1.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.horses1.buyWeight[k];

				end;

				for k = 1,4 do
					iFillType = RNS.horses2.fillType[k];
					myAnimalType = g_animalManager:getAnimalByFillType(iFillType);
-- input
					myAnimalType.seasons.straw = 285 * RNS.horses2.strawPerDay[k]/RN.commodityDensity.ROUNDBALE_WHEAT;
					myAnimalType.seasons.water = RNS.horses2.waterPerDayPerKg[k];
					myAnimalType.seasons.food = RNS.horses2.foodPerDayPerKg[k];
-- weight
					myAnimalType.seasons.buyWeight = RNS.horses2.buyWeight[k];
					myAnimalType.seasons.bornWeight = RNS.horses2.bornWeight[k];
-- output
					myAnimalType.seasons.milk = RNS.horses2.milkPerDay[k];
					myAnimalType.seasons.manure = RNS.horses2.manurePerDayPerKg[k];
					myAnimalType.seasons.liquidManure =	RNS.horses2.liquidManure[k];
					myAnimalType.seasons.foodSpillage = RNS.horses2.foodSpillage[k];
-- store
					myAnimalType.seasons.buyPrice = RNS.horses2.buyPriceMultiplier[k];
					myAnimalType.seasons.baseSellPrice = RNS.horses2.baseSellPrice[k];
					myAnimalType.seasons.pricePerKg = RNS.horses2.pricePerKg[k];
					myAnimalType.seasons.priceDropAge = RNS.horses2.priceDropAge[k];
					myAnimalType.seasons.transportPrice = math.min(RNS.horses2.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.seasons.buyAge = RNS.horses2.buyAge[k];
					myAnimalType.seasons.buyIsFemale = RNS.horses2.buyIsFemale[k];
					myAnimalType.seasons.liveryIncome  = RNS.horses2.liveryIncome[k];
					myAnimalType.seasons.trainingDifficulty = RNS.horses2.trainingDifficulty[k];

					myAnimalType.storeInfo.buyPrice = RNS.horses2.buyPriceMultiplier[k] * RNS.horses2.buyWeight[k] * RNS.horses2.pricePerKg[k];
					myAnimalType.storeInfo.baseSellPrice = RNS.horses2.baseSellPrice[k];
					myAnimalType.storeInfo.pricePerKg = RNS.horses2.pricePerKg[k];
					myAnimalType.storeInfo.priceDropAge = RNS.horses2.priceDropAge[k];
					myAnimalType.storeInfo.transportPrice = math.min(RNS.horses2.transportPrice[k], 0.01 * myAnimalType.storeInfo.buyPrice);
					myAnimalType.storeInfo.buyAge = RNS.horses2.buyAge[k]/365;
					myAnimalType.storeInfo.buyIsFemale = RNS.horses2.buyIsFemale[k];
					myAnimalType.storeInfo.buyWeight = RNS.horses2.buyWeight[k];

				end;

				RNS.notRunYetRealNumbersAnimalCareSeasons = false;
				RNS.upStartRealNumbersAnimalCareSeasons = false;
			end;
		end;
	end;

end;
function RealNumbersAnimalCareSeasons:draw()
end;
function RealNumbersAnimalCareSeasons:deleteMap()
end;
function RealNumbersAnimalCareSeasons:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersAnimalCareSeasons);
