--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersAnnualFeedPrediction by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.7 Compatible with Seasons
-- 30.11.2018 - 21.05.2020

-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
--]]

RealNumbersAnnualFeedPrediction = {};

function RealNumbersAnnualFeedPrediction:loadMap(name)
	local textWidth = 40; 					-- text width in log file

--[[
RN.cropBonusYieldLitersPerHa[fruitName]
RN.windrowYieldLitersPerHa[fruitName]
RN.numberRoundBalesPerHa[fruitName]
RN.numberSquareBalesPerHa[fruitName]
RN.cropPricePerLiter[fruitName]
--]]

	print("\nFS19_RealLifeNumbers: RealNumbersAnnualFeedPrediction active\n")

	RNS.cows1.color              = {   "BROWN",       "BROWN_WHITE",         "BLACK",       "BLACK_WHITE"    };
	RNS.cows1.type               = {  "Limousin",       "Ayrshire",          "Saler",         "Holstein"     };
	RNS.cows1.matureWeight		 = {    1000,              540,               1000,                680       };  -- kg
	RNS.cows1.weightDay          = {     365,              365,                365,                365       };  -- Age (in days) of known weight
	RNS.cows1.weightM            = {     566,              480,                516,                495       };  -- kg
	RNS.cows1.weightF            = {     420,              300,                396,                309       };  -- kg
	RNS.cows1.linGrowthPct		 = {      85,               85,                 85,                 85       };  -- %
	RNS.cows1.monthsToLevelOut   = {      24,               24,                 24,                 24       };  -- months to growth levels out
	RNS.cows1.slaughterAge       = {     365,              365,                365,                365       };  -- age of slaughter in days
	RNS.cows1.numberMature       = {      80,               80,                 80,                 80       };  -- number of mature animals
	RNS.cows1.strawPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.cows1.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.cows1.silagePercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.cows1.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.cows1.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters



	RNS.cows1.numberOfspr = {};
	RNS.cows1.males = {};
	RNS.cows1.females = {};
	RNS.cows1.linPeakWeight = {};
	RNS.cows1.daysToLevel = {};
	RNS.cows1.gainPerDayM = {};
	RNS.cows1.gainPerDayF = {};
	RNS.cows1.slaugtherWeightM = {};
	RNS.cows1.slaugtherWeightF = {};
	RNS.cows1.averageWeightM = {};
	RNS.cows1.averageWeightF = {};
	RNS.cows1.matureWater = {};
	RNS.cows1.offsprWaterM = {};
	RNS.cows1.offsprWaterF = {};
	RNS.cows1.breedWater = {};
	RNS.cows1.matureFeed = {};
	RNS.cows1.offsprFeedM = {};
 	RNS.cows1.offsprFeedF = {};
	RNS.cows1.breedFeed = {};
	RNS.cows1.troughFeed = {};
    RNS.cows1.mixDensity = {};
	RNS.cows1.mixVolume = {};
	RNS.cows1.troughStraw = {};
	RNS.cows1.troughHay = {};
	RNS.cows1.troughSilage = {};
	RNS.cows1.bedStraw = {};
	RNS.cows1.straw = {};
	RNS.cows1.strawRoundBales = {};
	RNS.cows1.strawSquareBales = {};
	RNS.cows1.hayRoundBales = {};
	RNS.cows1.haySquareBales = {};
	RNS.cows1.silageRoundBales = {};
    RNS.cows1.silageSquareBales = {};
	
	RNS.cows1.matureManure = {};
	RNS.cows1.offsprManureM = {};
	RNS.cows1.offsprManureF = {};
	RNS.cows1.famManure = {};
	RNS.cows1.breedManure = {};
	
	RNS.cows1.matureSlurry = {};
	RNS.cows1.offsprSlurryF = {};
	RNS.cows1.offsprSlurryM = {};
	RNS.cows1.famSlurry = {};
	RNS.cows1.breedSlurry = {};
	
	RNS.cows1.wheatHa = {};
	RNS.cows1.hayHa = {};
	RNS.cows1.silageHa = {};

	for k = 1,4 do
		RNS.cows1.numberOfspr[k]       = RNS.cows1.numberMature[k] * RNS.cows1.averageLitterSize[k];
		RNS.cows1.males[k]             = (1 - RNS.cows1.femalePercentage[k]) * RNS.cows1.numberOfspr[k];
		RNS.cows1.females[k]            = RNS.cows1.femalePercentage[k] * RNS.cows1.numberOfspr[k];
		RNS.cows1.gainPerDayM[k]       = (RNS.cows1.weightM[k] - RNS.cows1.bornWeight[k])/RNS.cows1.weightDay[k];
		RNS.cows1.gainPerDayF[k]       = (RNS.cows1.weightF[k] - RNS.cows1.bornWeight[k])/RNS.cows1.weightDay[k];
		RNS.cows1.slaugtherWeightM[k]  = RNS.cows1.bornWeight[k] + RNS.cows1.gainPerDayM[k] * RNS.cows1.slaughterAge[k];
		RNS.cows1.slaugtherWeightF[k]  = RNS.cows1.bornWeight[k] + RNS.cows1.gainPerDayF[k] * RNS.cows1.slaughterAge[k];
		RNS.cows1.averageWeightM[k]    = 0.5 * (RNS.cows1.slaugtherWeightM[k] + RNS.cows1.bornWeight[k]);
		RNS.cows1.averageWeightF[k]    = 0.5 * (RNS.cows1.slaugtherWeightF[k] + RNS.cows1.bornWeight[k]);

		RNS.cows1.matureWater[k]       = 365 * RNS.cows1.numberMature[k] * RNS.cows1.matureWeight[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.offsprWaterM[k]      = RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.offsprWaterF[k]      = RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.waterPerDayPerKg[k];
		RNS.cows1.breedWater[k]        = RNS.cows1.matureWater[k] + RNS.cows1.offsprWaterM[k] + RNS.cows1.offsprWaterF[k];

		RNS.cows1.matureManure[k]      = 365 * RNS.cows1.matureWeight[k] * RNS.cows1.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.cows1.offsprManureM[k]     = RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.manurePerDayPerKg[k];
		RNS.cows1.offsprManureF[k]     = RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.manurePerDayPerKg[k];
		RNS.cows1.breedManure[k]       = RNS.cows1.matureManure[k] + RNS.cows1.offsprManureM[k] + RNS.cows1.offsprManureF[k];

		RNS.cows1.matureSlurry[k]      = 365 * RNS.cows1.matureWeight[k] * RNS.cows1.liquidManure[k];		-- Slurry per mature animal per year
		RNS.cows1.offsprSlurryM[k]     = RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.liquidManure[k];
		RNS.cows1.offsprSlurryF[k]     = RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.liquidManure[k];
		RNS.cows1.breedSlurry[k]       = RNS.cows1.matureSlurry[k] + RNS.cows1.offsprSlurryM[k] + RNS.cows1.offsprSlurryF[k];

		RNS.cows1.matureFeed[k]        = 365 * RNS.cows1.numberMature[k] * RNS.cows1.matureWeight[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.offsprFeedM[k]       = RNS.cows1.males[k]   * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightM[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.offsprFeedF[k]       = RNS.cows1.females[k] * RNS.cows1.slaughterAge[k] * RNS.cows1.averageWeightF[k] * RNS.cows1.foodPerDayPerKg[k];
		RNS.cows1.breedFeed[k]         = RNS.cows1.matureFeed[k] + RNS.cows1.offsprFeedM[k] + RNS.cows1.offsprFeedF[k];
		RNS.cows1.troughFeed[k]        = RNS.cows1.foodTroughFraction[k] * RNS.cows1.breedFeed[k];
		RNS.cows1.mixDensity[k]		   = (RN.commodityDensity.SQUAREBALE_WHEAT * RNS.cows1.strawPercentage[k] + RN.commodityDensity.SQUAREBALE_DRYGRASS * RNS.cows1.hayPercentage[k] + RN.commodityDensity.SQUAREBALE_SILAGE * RNS.cows1.silagePercentage[k])/100;
		RNS.cows1.mixVolume[k]         = RNS.cows1.troughFeed[k]/RNS.cows1.mixDensity[k];
		RNS.cows1.troughStraw[k]       = (RNS.cows1.strawPercentage[k]/100)  * RNS.cows1.mixVolume[k];
		RNS.cows1.troughHay[k]         = (RNS.cows1.hayPercentage[k]/100)    * RNS.cows1.mixVolume[k];
		RNS.cows1.troughSilage[k]      = (RNS.cows1.silagePercentage[k]/100) * RNS.cows1.mixVolume[k];

		RNS.cows1.bedStraw[k]          = 365 * RNS.cows1.numberMature[k] * RNS.cows1.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.cows1.bedStraw[k]          = RNS.cows1.bedStraw[k] + RNS.cows1.slaughterAge[k] * RNS.cows1.numberMature[k] * RNS.cows1.averageLitterSize[k] * RNS.cows1.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;

		RNS.cows1.straw[k]             = RNS.cows1.bedStraw[k] + RNS.cows1.troughStraw[k];

		RNS.cows1.strawRoundBales[k]   = RNS.cows1.straw[k] / RNS.cows1.roundBaleVolume[k];
		RNS.cows1.strawSquareBales[k]  = RNS.cows1.straw[k] / RNS.cows1.squareBaleVolume[k];
		RNS.cows1.hayRoundBales[k]     = RNS.cows1.troughHay[k] / RNS.cows1.roundBaleVolume[k];
		RNS.cows1.haySquareBales[k]    = RNS.cows1.troughHay[k] / RNS.cows1.squareBaleVolume[k];
		RNS.cows1.silageRoundBales[k]  = RNS.cows1.troughSilage[k] / RNS.cows1.roundBaleVolume[k];
        RNS.cows1.silageSquareBales[k] = RNS.cows1.troughSilage[k] / RNS.cows1.squareBaleVolume[k];

		RNS.cows1.wheatHa[k]           = RNS.cows1.straw[k] / RN.windrowYieldLitersPerHa["WHEAT"];
		RNS.cows1.hayHa[k]             = RNS.cows1.troughHay[k] / RN.windrowYieldLitersPerHa["DRYGRASS"];
		RNS.cows1.silageHa[k]          = RNS.cows1.troughSilage[k] / RN.windrowYieldLitersPerHa["GRASS"];

		if RN.isDebug then
			print(" ");
			print("COWS");
			print(" ");
			print(RNS.cows1.type[k]);
			myPrint("Number of mature animals",RNS.cows1.numberMature[k],textWidth, " ");
			myPrint("Number of offsprings, males",RNS.cows1.males[k],textWidth, " ");
			myPrint("Number of offsprings, females",RNS.cows1.females[k],textWidth, " ");
			myPrint("Average weight males", RNS.cows1.averageWeightM[k],textWidth, " kg");
			myPrint("Average weight females", RNS.cows1.averageWeightF[k],textWidth, " kg");
			myPrintFloat("Average weight gain, males", RNS.cows1.gainPerDayM[k],textWidth, " kg/day");
			myPrintFloat("Average weight gain, females", RNS.cows1.gainPerDayF[k],textWidth, " kg/day");
			myPrint("Slaughter age", RNS.cows1.slaughterAge[k],textWidth, " days");
			myPrint("Slaughter weight, male", RNS.cows1.slaugtherWeightM[k],textWidth, " kg");
			myPrint("Slaughter weight, female", RNS.cows1.slaugtherWeightF[k],textWidth, " kg");
			myPrint("Herd manure per year", RNS.cows1.breedManure[k],textWidth, " L/year");
			myPrint("Herd slurry per year", RNS.cows1.breedSlurry[k],textWidth, " L/year");
			myPrint("Water per year", RNS.cows1.breedWater[k],textWidth," L/year");
			myPrint("Herd feed intake", RNS.cows1.breedFeed[k],textWidth, " kg/year");
			myPrint("Herd trough feed", RNS.cows1.troughFeed[k],textWidth, " kg/year");
			myPrintFloat("TMR density", RNS.cows1.mixDensity[k],textWidth, " kg/L");
			myPrint("Herd TMR volume", RNS.cows1.mixVolume[k],textWidth, " L/year");
			myPrint("Herd trough silage", RNS.cows1.troughSilage[k],textWidth, " L/year");
			myPrint("Herd trough hay", RNS.cows1.troughHay[k],textWidth, " L/year");
			myPrint("Herd trough straw", RNS.cows1.troughStraw[k],textWidth, " L/year");
			myPrint("Herd bedding straw", RNS.cows1.bedStraw[k],textWidth, " L/year");
			myPrint("Herd total straw", RNS.cows1.straw[k],textWidth, " L/year");
			myPrint("Round straw bales", RNS.cows1.strawRoundBales[k],textWidth, " Bales/year");
			myPrint("Square straw bales", RNS.cows1.strawSquareBales[k],textWidth, " Bales/year");
			myPrint("Round hay bales", RNS.cows1.hayRoundBales[k],textWidth, " Bales/year");
			myPrint("Square hay bales", RNS.cows1.haySquareBales[k],textWidth, " Bales/year");
			myPrint("Round silage bales", RNS.cows1.silageRoundBales[k],textWidth, " Bales/year");
			myPrint("Square silage bales", RNS.cows1.silageSquareBales[k],textWidth, " Bales/year");
			myPrintFloat("Straw hectares",RNS.cows1.wheatHa[k],textWidth, " Ha");
			myPrintFloat("Hay hectares",RNS.cows1.hayHa[k],textWidth, " Ha");
			myPrintFloat("Silage hectares",RNS.cows1.silageHa[k],textWidth, " Ha");
			print(" ");
		end;
	end;



	RNS.cows2.color              = {"BRAHMAN_BROWN", "BRAHMAN_WHITE", "BRAHMAN_LIGHT_BROWN","BRAHMAN_GREY"   };
	RNS.cows2.type               = {"Brahman (brown)","Brahman (white)","Brahman (light brown)","Brahman (grey)"};
	RNS.cows2.matureWeight		 = {     900,              900,                900,                900       };  -- kg
	RNS.cows2.weightDay          = {     365,              365,                365,                365       };  -- Age (in days) of known weight
	RNS.cows2.weightM            = {     566,              480,                516,                495       };  -- kg
	RNS.cows2.weightF            = {     420,              300,                396,                309       };  -- kg
	RNS.cows2.linGrowthPct		 = {      85,               85,                 85,                 85       };  -- %
	RNS.cows2.monthsToLevelOut   = {      24,               24,                 24,                 24       };  -- months to growth levels out
	RNS.cows2.slaughterAge       = {     365,              365,                365,                365       };  -- age of slaughter in days
	RNS.cows2.numberMature       = {      60,               60,                 60,                 60       };  -- number of mature animals
	RNS.cows2.strawPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.cows2.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.cows2.silagePercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.cows2.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.cows2.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters


	RNS.cows2.numberOfspr = {};
	RNS.cows2.males = {};
	RNS.cows2.females = {};
	RNS.cows2.linPeakWeight = {};
	RNS.cows2.daysToLevel = {};
	RNS.cows2.gainPerDayM = {};
	RNS.cows2.gainPerDayF = {};
	RNS.cows2.slaugtherWeightM = {};
	RNS.cows2.slaugtherWeightF = {};
	RNS.cows2.averageWeightM = {};
	RNS.cows2.averageWeightF = {};
	RNS.cows2.matureWater = {};
	RNS.cows2.offsprWaterM = {};
	RNS.cows2.offsprWaterF = {};
	RNS.cows2.breedWater = {};
	RNS.cows2.matureFeed = {};
	RNS.cows2.offsprFeedM = {};
 	RNS.cows2.offsprFeedF = {};
	RNS.cows2.breedFeed = {};
	RNS.cows2.troughFeed = {};
    RNS.cows2.mixDensity = {};
	RNS.cows2.mixVolume = {};
	RNS.cows2.troughStraw = {};
	RNS.cows2.troughHay = {};
	RNS.cows2.troughSilage = {};
	RNS.cows2.bedStraw = {};
	RNS.cows2.straw = {};
	RNS.cows2.strawRoundBales = {};
	RNS.cows2.strawSquareBales = {};
	RNS.cows2.hayRoundBales = {};
	RNS.cows2.haySquareBales = {};
	RNS.cows2.silageRoundBales = {};
    RNS.cows2.silageSquareBales = {};
	
	RNS.cows2.matureManure = {};
	RNS.cows2.offsprManureM = {};
	RNS.cows2.offsprManureF = {};
	RNS.cows2.famManure = {};
	RNS.cows2.breedManure = {};
	
	RNS.cows2.matureSlurry = {};
	RNS.cows2.offsprSlurryM = {};
	RNS.cows2.offsprSlurryF = {};
	RNS.cows2.famSlurry = {};
	RNS.cows2.breedSlurry = {};
	
	RNS.cows2.wheatHa = {};
	RNS.cows2.hayHa = {};
	RNS.cows2.silageHa = {};

	for k = 1,4 do
		RNS.cows2.numberOfspr[k]       = RNS.cows2.numberMature[k] * RNS.cows2.averageLitterSize[k];
		RNS.cows2.males[k]             = (1 - RNS.cows2.femalePercentage[k]) * RNS.cows2.numberOfspr[k];
		RNS.cows2.females[k]            = RNS.cows2.femalePercentage[k] * RNS.cows2.numberOfspr[k];
		RNS.cows2.gainPerDayM[k]       = (RNS.cows2.weightM[k] - RNS.cows2.bornWeight[k])/RNS.cows2.weightDay[k];
		RNS.cows2.gainPerDayF[k]       = (RNS.cows2.weightF[k] - RNS.cows2.bornWeight[k])/RNS.cows2.weightDay[k];
		RNS.cows2.slaugtherWeightM[k]  = RNS.cows2.bornWeight[k] + RNS.cows2.gainPerDayM[k] * RNS.cows2.slaughterAge[k];
		RNS.cows2.slaugtherWeightF[k]  = RNS.cows2.bornWeight[k] + RNS.cows2.gainPerDayF[k] * RNS.cows2.slaughterAge[k];
		RNS.cows2.averageWeightM[k]    = 0.5 * (RNS.cows2.slaugtherWeightM[k] + RNS.cows2.bornWeight[k]);
		RNS.cows2.averageWeightF[k]    = 0.5 * (RNS.cows2.slaugtherWeightF[k] + RNS.cows2.bornWeight[k]);

		RNS.cows2.matureWater[k]       = 365 * RNS.cows2.numberMature[k] * RNS.cows2.matureWeight[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.offsprWaterM[k]      = RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.offsprWaterF[k]      = RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.waterPerDayPerKg[k];
		RNS.cows2.breedWater[k]        = RNS.cows2.matureWater[k] + RNS.cows2.offsprWaterM[k] + RNS.cows2.offsprWaterF[k];

		RNS.cows2.matureManure[k]      = 365 * RNS.cows2.matureWeight[k] * RNS.cows2.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.cows2.offsprManureM[k]     = RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.manurePerDayPerKg[k];
		RNS.cows2.offsprManureF[k]     = RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.manurePerDayPerKg[k];
		RNS.cows2.breedManure[k]       = RNS.cows2.matureManure[k] + RNS.cows2.offsprManureM[k] + RNS.cows2.offsprManureF[k];

		RNS.cows2.matureSlurry[k]      = 365 * RNS.cows2.matureWeight[k] * RNS.cows2.liquidManure[k];		-- Slurry per mature animal per year
		RNS.cows2.offsprSlurryM[k]     = RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.liquidManure[k];
		RNS.cows2.offsprSlurryF[k]     = RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.liquidManure[k];
		RNS.cows2.breedSlurry[k]       = RNS.cows2.matureSlurry[k] + RNS.cows2.offsprSlurryM[k] + RNS.cows2.offsprSlurryF[k];

		RNS.cows2.matureFeed[k]        = 365 * RNS.cows2.numberMature[k] * RNS.cows2.matureWeight[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.offsprFeedM[k]       = RNS.cows2.males[k]   * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightM[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.offsprFeedF[k]       = RNS.cows2.females[k] * RNS.cows2.slaughterAge[k] * RNS.cows2.averageWeightF[k] * RNS.cows2.foodPerDayPerKg[k];
		RNS.cows2.breedFeed[k]         = RNS.cows2.matureFeed[k] + RNS.cows2.offsprFeedM[k] + RNS.cows2.offsprFeedF[k];
		RNS.cows2.troughFeed[k]        = RNS.cows2.foodTroughFraction[k] * RNS.cows2.breedFeed[k];
		RNS.cows2.mixDensity[k]		   = (RN.commodityDensity.SQUAREBALE_WHEAT * RNS.cows2.strawPercentage[k] + RN.commodityDensity.SQUAREBALE_DRYGRASS * RNS.cows2.hayPercentage[k] + RN.commodityDensity.SQUAREBALE_SILAGE * RNS.cows2.silagePercentage[k])/100;
		RNS.cows2.mixVolume[k]         = RNS.cows2.troughFeed[k]/RNS.cows2.mixDensity[k];
		RNS.cows2.troughStraw[k]       = (RNS.cows2.strawPercentage[k]/100)  * RNS.cows2.mixVolume[k];
		RNS.cows2.troughHay[k]         = (RNS.cows2.hayPercentage[k]/100)    * RNS.cows2.mixVolume[k];
		RNS.cows2.troughSilage[k]      = (RNS.cows2.silagePercentage[k]/100) * RNS.cows2.mixVolume[k];

		RNS.cows2.bedStraw[k]          = 365 * RNS.cows2.numberMature[k] * RNS.cows2.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.cows2.bedStraw[k]          = RNS.cows2.bedStraw[k] + RNS.cows2.slaughterAge[k] * RNS.cows2.numberMature[k] * RNS.cows2.averageLitterSize[k] * RNS.cows2.strawPerDay[k] / RN.commodityDensity.SQUAREBALE_WHEAT;

		RNS.cows2.straw[k]             = RNS.cows2.bedStraw[k] + RNS.cows2.troughStraw[k];

		RNS.cows2.strawRoundBales[k]   = RNS.cows2.straw[k] / RNS.cows2.roundBaleVolume[k];
		RNS.cows2.strawSquareBales[k]  = RNS.cows2.straw[k] / RNS.cows2.squareBaleVolume[k];
		RNS.cows2.hayRoundBales[k]     = RNS.cows2.troughHay[k] / RNS.cows2.roundBaleVolume[k];
		RNS.cows2.haySquareBales[k]    = RNS.cows2.troughHay[k] / RNS.cows2.squareBaleVolume[k];
		RNS.cows2.silageRoundBales[k]  = RNS.cows2.troughSilage[k] / RNS.cows2.roundBaleVolume[k];
        RNS.cows2.silageSquareBales[k] = RNS.cows2.troughSilage[k] / RNS.cows2.squareBaleVolume[k];

		RNS.cows2.wheatHa[k]           = RNS.cows2.straw[k] / RN.windrowYieldLitersPerHa["WHEAT"];
		RNS.cows2.hayHa[k]             = RNS.cows2.troughHay[k] / RN.windrowYieldLitersPerHa["DRYGRASS"];
		RNS.cows2.silageHa[k]          = RNS.cows2.troughSilage[k] / RN.windrowYieldLitersPerHa["GRASS"];

		if RN.isDebug then
			print(" ");
			print("COWS");
			print(" ");
			print(RNS.cows2.type[k]);
			myPrint("Number of mature animals",RNS.cows2.numberMature[k],textWidth, " ");
			myPrint("Number of offsprings, males",RNS.cows2.males[k],textWidth, " ");
			myPrint("Number of offsprings, females",RNS.cows2.females[k],textWidth, " ");
			myPrint("Average weight males", RNS.cows2.averageWeightM[k],textWidth, " kg");
			myPrint("Average weight females", RNS.cows2.averageWeightF[k],textWidth, " kg");
			myPrintFloat("Average weight gain, males", RNS.cows2.gainPerDayM[k],textWidth, " kg/day");
			myPrintFloat("Average weight gain, females", RNS.cows2.gainPerDayF[k],textWidth, " kg/day");
			myPrint("Slaughter age", RNS.cows2.slaughterAge[k],textWidth, " days");
			myPrint("Slaughter weight, male", RNS.cows2.slaugtherWeightM[k],textWidth, " kg");
			myPrint("Slaughter weight, female", RNS.cows2.slaugtherWeightF[k],textWidth, " kg");
			myPrint("Herd manure per year", RNS.cows2.breedManure[k],textWidth, " L/year");
			myPrint("Herd slurry per year", RNS.cows2.breedSlurry[k],textWidth, " L/year");
			myPrint("Water per year", RNS.cows2.breedWater[k],textWidth," L/year");
			myPrint("Herd feed intake", RNS.cows2.breedFeed[k],textWidth, " kg/year");
			myPrint("Herd trough feed", RNS.cows2.troughFeed[k],textWidth, " kg/year");
			myPrintFloat("TMR density", RNS.cows2.mixDensity[k],textWidth, " kg/L");
			myPrint("Herd TMR volume", RNS.cows2.mixVolume[k],textWidth, " L/year");
			myPrint("Herd trough silage", RNS.cows2.troughSilage[k],textWidth, " L/year");
			myPrint("Herd trough hay", RNS.cows2.troughHay[k],textWidth, " L/year");
			myPrint("Herd trough straw", RNS.cows2.troughStraw[k],textWidth, " L/year");
			myPrint("Herd bedding straw", RNS.cows2.bedStraw[k],textWidth, " L/year");
			myPrint("Herd total straw", RNS.cows2.straw[k],textWidth, " L/year");
			myPrint("Round straw bales", RNS.cows2.strawRoundBales[k],textWidth, " Bales/year");
			myPrint("Square straw bales", RNS.cows2.strawSquareBales[k],textWidth, " Bales/year");
			myPrint("Round hay bales", RNS.cows2.hayRoundBales[k],textWidth, " Bales/year");
			myPrint("Square hay bales", RNS.cows2.haySquareBales[k],textWidth, " Bales/year");
			myPrint("Round silage bales", RNS.cows2.silageRoundBales[k],textWidth, " Bales/year");
			myPrint("Square silage bales", RNS.cows2.silageSquareBales[k],textWidth, " Bales/year");
			myPrintFloat("Straw hectares",RNS.cows2.wheatHa[k],textWidth, " Ha");
			myPrintFloat("Hay hectares",RNS.cows2.hayHa[k],textWidth, " Ha");
			myPrintFloat("Silage hectares",RNS.cows2.silageHa[k],textWidth, " Ha");
			print(" ");
		end;
	end;

-- https://iamcountryside.com/pigs/10-pig-breeds/

	RNS.pigs.color               = {     "RED",         "WHITE",          "BLACK_WHITE",         "BLACK"     };
	RNS.pigs.type                = { "Yorkshire","Gloucestershire Old Spot","Spotted",         "Berkshire"   };
	RNS.pigs.matureWeight		 = {     250,              250,                250,                250       };  -- kg
	RNS.pigs.weightDay           = {     120,              120,                120,                120       };  -- Age (in days) of known weight
	RNS.pigs.weight              = {     122,              122,                122,                122       };  -- kg
	RNS.pigs.slaughterAge      	 = {     120,              120,                120,                120       };  -- age of slaughter in days
	RNS.pigs.numberMature        = {      20,               50,                 20,                 50       };  -- number of mature animals
	RNS.pigs.strawPerDayPerKg	 = {    0.01,             0.01,               0.01,               0.01       };  -- kg straw per day per kg bodyweight
	RNS.pigs.cerealPercentage    = {      25,               25,                 25,                 25       };  -- percentage of feed from straw
	RNS.pigs.cornPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.pigs.proteinPercentage   = {      25,               25,                 25,                 25       };  -- perentage of feed from silage
	RNS.pigs.roundBaleVolume     = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.pigs.squareBaleVolume    = {    2600,             2600,               2600,               2600       };  -- Liters

	RNS.pigs.numberOfspr = {};
	RNS.pigs.gainPerDay = {};
	RNS.pigs.slaugtherWeight = {};
	RNS.pigs.averageWeight = {};
	RNS.pigs.matureWater = {};
	RNS.pigs.offsprWater = {};
	RNS.pigs.famWater = {};
	RNS.pigs.breedWater = {};
	RNS.pigs.matureFeed = {};
	RNS.pigs.offsprFeed = {};
	RNS.pigs.famFeed = {};
	RNS.pigs.breedFeed = {};
	RNS.pigs.troughFeed = {};
    RNS.pigs.mixDensity = {};
	RNS.pigs.mixVolume = {};
	RNS.pigs.troughCorn = {};
	RNS.pigs.troughCereal = {};
	RNS.pigs.troughProtein = {};
	RNS.pigs.bedStraw = {};
	RNS.pigs.straw = {};
	RNS.pigs.strawRoundBales = {};
	RNS.pigs.strawSquareBales = {};

	RNS.pigs.matureManure = {};
	RNS.pigs.offsprManure = {};
	RNS.pigs.famManure = {};
	RNS.pigs.breedManure = {};
	
	RNS.pigs.matureSlurry = {};
	RNS.pigs.offsprSlurry = {};
	RNS.pigs.famSlurry = {};
	RNS.pigs.breedSlurry = {};

	RNS.pigs.wheatHa = {};
	RNS.pigs.cornHa = {};
	RNS.pigs.soybeanHa = {};
	RNS.pigs.strawHa = {};



	for k = 1,4 do
		RNS.pigs.numberOfspr[k]       = RNS.pigs.numberMature[k] * RNS.pigs.averageLitterSize[k];
		RNS.pigs.gainPerDay[k]        = (RNS.pigs.weight[k] - RNS.pigs.bornWeight[k])/RNS.pigs.weightDay[k];
		RNS.pigs.slaugtherWeight[k]   = RNS.pigs.bornWeight[k] + RNS.pigs.gainPerDay[k] * RNS.pigs.slaughterAge[k];
		RNS.pigs.averageWeight[k]     = 0.5 * (RNS.pigs.slaugtherWeight[k] + RNS.pigs.bornWeight[k]);

		RNS.pigs.matureWater[k]       = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.waterPerDayPerKg[k];
		RNS.pigs.offsprWater[k]       = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.waterPerDayPerKg[k];
		RNS.pigs.famWater[k]          = RNS.pigs.matureWater[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprWater[k];
		RNS.pigs.breedWater[k]        = RNS.pigs.famWater[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureManure[k]      = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.manurePerDayPerKg[k];		-- Manure per mature animal per year
		RNS.pigs.offsprManure[k]      = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.manurePerDayPerKg[k];	-- Manure per offspring per year
		RNS.pigs.famManure[k]         = RNS.pigs.matureManure[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprManure[k]; -- Manure per mother and her offspring per year
		RNS.pigs.breedManure[k]       = RNS.pigs.famManure[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureSlurry[k]      = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.liquidManure[k];		-- Slurry per mature animal per year
		RNS.pigs.offsprSlurry[k]      = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.liquidManure[k];	-- Slurry per offspring per year
		RNS.pigs.famSlurry[k]         = RNS.pigs.matureSlurry[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprSlurry[k]; -- Slurry per mother and her offspring per year
		RNS.pigs.breedSlurry[k]       = RNS.pigs.famSlurry[k] * RNS.pigs.numberMature[k];

		RNS.pigs.matureFeed[k]        = 365 * RNS.pigs.matureWeight[k] * RNS.pigs.foodPerDayPerKg[k];
		RNS.pigs.offsprFeed[k]        = 182.5 * RNS.pigs.averageWeight[k] * RNS.pigs.foodPerDayPerKg[k];
		RNS.pigs.famFeed[k]           = RNS.pigs.matureFeed[k] + 2 * RNS.pigs.averageLitterSize[k] * RNS.pigs.offsprFeed[k];
		RNS.pigs.breedFeed[k]         = RNS.pigs.famFeed[k] * RNS.pigs.numberMature[k];
		RNS.pigs.troughFeed[k]        = RNS.pigs.foodTroughFraction[k] * RNS.pigs.breedFeed[k];
		RNS.pigs.mixDensity[k]		  = (RN.cropDensity.WHEAT * RNS.pigs.cerealPercentage[k] + RN.cropDensity.MAIZE * RNS.pigs.cornPercentage[k] + RN.cropDensity.SOYBEAN * RNS.pigs.proteinPercentage[k])/100;
		RNS.pigs.mixVolume[k]         = RNS.pigs.troughFeed[k]/RNS.pigs.mixDensity[k];
		RNS.pigs.troughCereal[k]      = (RNS.pigs.cerealPercentage[k]/100)  * RNS.pigs.mixVolume[k];
		RNS.pigs.troughCorn[k]        = (RNS.pigs.cornPercentage[k]/100)    * RNS.pigs.mixVolume[k];
		RNS.pigs.troughProtein[k]     = (RNS.pigs.proteinPercentage[k]/100) * RNS.pigs.mixVolume[k];

		RNS.pigs.bedStraw[k]          = 365 * RNS.pigs.numberMature[k] * RNS.pigs.matureWeight[k] * RNS.pigs.strawPerDayPerKg[k] / RN.commodityDensity.SQUAREBALE_WHEAT;
		RNS.pigs.bedStraw[k]          = RNS.pigs.bedStraw[k]  + RNS.pigs.numberMature[k] * 2 * RNS.pigs.slaughterAge[k] * RNS.pigs.averageLitterSize[k] * RNS.pigs.averageWeight[k] * RNS.pigs.strawPerDayPerKg[k] / RN.commodityDensity.SQUAREBALE_WHEAT;

		RNS.pigs.strawRoundBales[k]   = RNS.pigs.bedStraw[k] / RNS.pigs.roundBaleVolume[k];
		RNS.pigs.strawSquareBales[k]  = RNS.pigs.bedStraw[k] / RNS.pigs.squareBaleVolume[k];

		RNS.pigs.wheatHa[k]           = RNS.pigs.troughCereal[k] / RN.cropBonusYieldLitersPerHa["WHEAT"];
		RNS.pigs.cornHa[k]            = RNS.pigs.troughCorn[k] / RN.cropBonusYieldLitersPerHa["MAIZE"];
		RNS.pigs.soybeanHa[k]         = RNS.pigs.troughProtein[k] / RN.cropBonusYieldLitersPerHa["SOYBEAN"];
		RNS.pigs.strawHa[k]			  = RNS.pigs.bedStraw[k] / RN.windrowYieldLitersPerHa["WHEAT"]

		if RN.isDebug then
			print(" ");
			print("PIGS");
			print(" ");
			print(RNS.pigs.type[k]);
			myPrint("Number of mature animals",RNS.pigs.numberMature[k],textWidth, " ");
			myPrint("Number of offsprings",2*RNS.pigs.numberOfspr[k],textWidth, " per year");
			myPrint("Average weight", RNS.pigs.averageWeight[k],textWidth, " kg");
			myPrintFloat("Average weight gain", RNS.pigs.gainPerDay[k],textWidth, " kg/day");
			myPrint("Slaughter age", RNS.pigs.slaughterAge[k],textWidth, " days");
			myPrint("Slaughter weight", RNS.pigs.slaugtherWeight[k],textWidth, " kg");
			myPrint("Herd manure per year", RNS.pigs.breedManure[k],textWidth, " L/year");
			myPrint("Herd slurry per year", RNS.pigs.breedSlurry[k],textWidth, " L/year");
			myPrint("Water per year", RNS.pigs.breedWater[k],textWidth," L/year");
			myPrint("Herd feed intake", RNS.pigs.breedFeed[k],textWidth, " kg/year");
			myPrint("Herd trough feed", RNS.pigs.troughFeed[k],textWidth, " kg/year");
			myPrintFloat("Feedmix density", RNS.pigs.mixDensity[k],textWidth, " kg/L");
			myPrint("Herd Feedmix volume", RNS.pigs.mixVolume[k],textWidth, " L/year");
			myPrint("Herd trough cereal", RNS.pigs.troughCereal[k],textWidth, " L/year");
			myPrint("Herd trough maize", RNS.pigs.troughCorn[k],textWidth, " L/year");
			myPrint("Herd trough soybean", RNS.pigs.troughProtein[k],textWidth, " L/year");
			myPrint("Herd bedding straw", RNS.pigs.bedStraw[k],textWidth, " L/year");

			myPrint("Round straw bales", RNS.pigs.strawRoundBales[k],textWidth, " Bales/year");
			myPrint("Square straw bales", RNS.pigs.strawSquareBales[k],textWidth, " Bales/year");

			myPrintFloat("Wheat hectares",RNS.pigs.wheatHa[k],textWidth, " Ha");
			myPrintFloat("Maize hectares",RNS.pigs.cornHa[k],textWidth, " Ha");
			myPrintFloat("Soybean hectares",RNS.pigs.soybeanHa[k],textWidth, " Ha");
			myPrintFloat("Straw hectares",RNS.pigs.strawHa[k],textWidth, " Ha");
			print(" ");
		end;
	end;

	RNS.sheep.color              = {   "WHITE",         "BROWN",          "BLACK_WHITE",          "BLACK"    };
	RNS.sheep.type               = {  "Dorset",         "Merino",           "Suffolk",            "Dorper"   };
	RNS.sheep.matureWeight		 = {      65,               65,                 65,                 65       };  -- kg
	RNS.sheep.weightDay          = {     240,              240,                240,                240       };  -- Age (in days) of known weight
	RNS.sheep.weight             = {      44,               44,                 44,                 44       };  -- kg
	RNS.sheep.slaughterAge       = {     240,              240,                240,                240       };  -- age of slaughter in days
	RNS.sheep.numberMature       = {     100,              100,                100,                100       };  -- number of mature animals
	RNS.sheep.grassPercentage    = {      50,               50,                 50,                 50       };  -- percentage of feed from straw
	RNS.sheep.hayPercentage      = {      50,               50,                 50,                 50       };  -- percentage of feed from hay
	RNS.sheep.roundBaleVolume    = {    1500,             1500,               1500,               1500       };  -- Liters
	RNS.sheep.squareBaleVolume   = {    2600,             2600,               2600,               2600       };  -- Liters

	RNS.sheep.numberOfspr = {};
	RNS.sheep.gainPerDay = {};
	RNS.sheep.slaugtherWeight = {};
	RNS.sheep.averageWeight = {};
	RNS.sheep.matureWater = {};
	RNS.sheep.offsprWater = {};
	RNS.sheep.famWater = {};
	RNS.sheep.breedWater = {};
	RNS.sheep.matureFeed = {};
	RNS.sheep.offsprFeed = {};
	RNS.sheep.famFeed = {};
	RNS.sheep.breedFeed = {};
	RNS.sheep.troughFeed = {};
    RNS.sheep.mixDensity = {};
	RNS.sheep.mixVolume = {};
	RNS.sheep.troughGrass = {};
	RNS.sheep.troughHay = {};
	RNS.sheep.hayRoundBales = {};
	RNS.sheep.haySquareBales = {};
	RNS.sheep.grassRoundBales = {};
    RNS.sheep.grassSquareBales = {};
	RNS.sheep.hayHa = {};
	RNS.sheep.grassHa = {};
	
	for k = 1,4 do
		RNS.sheep.numberOfspr[k]       = RNS.sheep.numberMature[k] * RNS.sheep.averageLitterSize[k];
		RNS.sheep.gainPerDay[k]        = (RNS.sheep.weight[k] - RNS.sheep.bornWeight[k])/RNS.sheep.weightDay[k];
		RNS.sheep.slaugtherWeight[k]   = RNS.sheep.bornWeight[k] + RNS.sheep.gainPerDay[k] * RNS.sheep.slaughterAge[k];
		RNS.sheep.averageWeight[k]     = 0.5 * (RNS.sheep.slaugtherWeight[k] + RNS.sheep.bornWeight[k]);

		RNS.sheep.matureWater[k]       = 365 * RNS.sheep.matureWeight[k] * RNS.sheep.waterPerDayPerKg[k];
		RNS.sheep.offsprWater[k]       = RNS.sheep.slaughterAge[k] * RNS.sheep.averageWeight[k] * RNS.sheep.waterPerDayPerKg[k];
		RNS.sheep.famWater[k]          = RNS.sheep.matureWater[k] + RNS.sheep.averageLitterSize[k] * RNS.sheep.offsprWater[k];
		RNS.sheep.breedWater[k]        = RNS.sheep.famWater[k] * RNS.sheep.numberMature[k];

		RNS.sheep.matureFeed[k]        = 365 * RNS.sheep.matureWeight[k] * RNS.sheep.foodPerDayPerKg[k];
		RNS.sheep.offsprFeed[k]        = RNS.sheep.slaughterAge[k] * RNS.sheep.averageWeight[k] * RNS.sheep.foodPerDayPerKg[k];
		RNS.sheep.famFeed[k]           = RNS.sheep.matureFeed[k] + RNS.sheep.averageLitterSize[k] * RNS.sheep.offsprFeed[k];
		RNS.sheep.breedFeed[k]         = RNS.sheep.famFeed[k] * RNS.sheep.numberMature[k];
		RNS.sheep.troughFeed[k]        = RNS.sheep.foodTroughFraction[k] * RNS.sheep.breedFeed[k];
		RNS.sheep.mixDensity[k]		   = (RN.commodityDensity.SQUAREBALE_GRASS * RNS.sheep.grassPercentage[k] + RN.commodityDensity.SQUAREBALE_DRYGRASS * RNS.sheep.hayPercentage[k])/100;
		RNS.sheep.mixVolume[k]         = RNS.sheep.troughFeed[k]/RNS.sheep.mixDensity[k];
		RNS.sheep.troughGrass[k]       = (RNS.sheep.grassPercentage[k]/100)  * RNS.sheep.mixVolume[k];
		RNS.sheep.troughHay[k]         = (RNS.sheep.hayPercentage[k]/100)    * RNS.sheep.mixVolume[k];

		RNS.sheep.grassRoundBales[k]   = RNS.sheep.troughGrass[k] / RNS.sheep.roundBaleVolume[k];
        RNS.sheep.grassSquareBales[k]  = RNS.sheep.troughGrass[k] / RNS.sheep.squareBaleVolume[k];
		RNS.sheep.hayRoundBales[k]     = RNS.sheep.troughHay[k] / RNS.sheep.roundBaleVolume[k];
		RNS.sheep.haySquareBales[k]    = RNS.sheep.troughHay[k] / RNS.sheep.squareBaleVolume[k];

		RNS.sheep.hayHa[k]             = RNS.sheep.troughHay[k] / RN.windrowYieldLitersPerHa["DRYGRASS"];
		RNS.sheep.grassHa[k]           = RNS.sheep.troughGrass[k] / RN.windrowYieldLitersPerHa["GRASS"];

		if RN.isDebug then
			print(" ");
			print("SHEEP");
			print(" ");
			print(RNS.sheep.type[k]);
			myPrint("Number of mature animals",RNS.sheep.numberMature[k],textWidth, " ");
			myPrint("Number of offsprings",RNS.sheep.numberOfspr[k],textWidth, " ");
			myPrint("Average weight", RNS.sheep.averageWeight[k],textWidth, " kg");
			myPrintFloat("Average weight gain", RNS.sheep.gainPerDay[k],textWidth, " kg/day");
			myPrint("Slaughter age", RNS.sheep.slaughterAge[k],textWidth, " days");
			myPrint("Slaughter weight", RNS.sheep.slaugtherWeight[k],textWidth, " kg");
			myPrint("Water per year", RNS.sheep.breedWater[k],textWidth," L/year");
			myPrint("Herd feed intake", RNS.sheep.breedFeed[k],textWidth, " kg/year");
			myPrint("Herd trough feed", RNS.sheep.troughFeed[k],textWidth, " kg/year");
			myPrintFloat("TMR density", RNS.sheep.mixDensity[k],textWidth, " kg/L");
			myPrint("Herd TMR volume", RNS.sheep.mixVolume[k],textWidth, " L/year");
			myPrint("Herd trough grass", RNS.sheep.troughGrass[k],textWidth, " L/year");
			myPrint("Herd trough hay", RNS.sheep.troughHay[k],textWidth, " L/year");
			myPrint("Round grass bales", RNS.sheep.grassRoundBales[k],textWidth, " Bales/year");
			myPrint("Square grass bales", RNS.sheep.grassSquareBales[k],textWidth, " Bales/year");
			myPrint("Round hay bales", RNS.sheep.hayRoundBales[k],textWidth, " Bales/year");
			myPrint("Square hay bales", RNS.sheep.haySquareBales[k],textWidth, " Bales/year");
			myPrintFloat("Hay hectares",RNS.sheep.hayHa[k],textWidth, " Ha");
			myPrintFloat("Grass hectares",RNS.sheep.grassHa[k],textWidth, " Ha");
			print(" ");
		end;
	end;


end;

function RealNumbersAnnualFeedPrediction:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersAnnualFeedPrediction:update(dt)
end;
function RealNumbersAnnualFeedPrediction:draw()
end;
function RealNumbersAnnualFeedPrediction:deleteMap()
end;
function RealNumbersAnnualFeedPrediction:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersAnnualFeedPrediction);
