--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersCropProductionCost by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.2.3.7 Compatible with Seasons
-- 30.11.2018 - 21.05.2020


RealNumbersCropProductionCost = {};

function myPrintCropCost(crop, textWidth, unit, S1, S2, S3, S4, S5, S6, S7)
	local text = crop..string.rep(" ",textWidth-string.len(crop))
	print(string.format("%s: %s %9.0f %9.0f %9.0f %9.0f %9.0f %9.0f %9.3f", text, unit, S1, S2, S3, S4, S5, S6, S7));
end;

function RealNumbersCropProductionCost:loadMap()
	local currency = " ";
	local isDebug = RN.isDebug;
	local isDebug2 = false;
    local textWidth = 18;
    local textWidth2 = 27;
	local textWidth3 = 40;
	local grossIncome  = 0;
	local netIncome  = 0;
	local fieldWork  = 0;
	local productCostPerHa = 0.0000;
	local feedCostPerLiter = 0.0000;
	local Fert  = 0;
	local Lime  = 0;
	local Seed  = 0;
	local Herbicide  = 0;
	local Rent  = 0;
	local profit = 0;

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	RN.fieldWorkCost.ASPARAGUS				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BARLEY					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.BEAN					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BEANS					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.BLACKBEANS				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CABBAGE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CANOLA					= RN.fieldWorkCost.CANOLA;
	RN.fieldWorkCost.CARROT					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.CHAFF					= RN.fieldWorkCost.MAIZESILAGE;
	RN.fieldWorkCost.COTTON					= 0;
	RN.fieldWorkCost.CRANBERRY				= 0;
	RN.fieldWorkCost.FORAGE					= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.HEMP					= 0;
	RN.fieldWorkCost.HOPS					= 0;
	RN.fieldWorkCost.INCARASE_GRASS			= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.LETTUCE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.MAIZE					= RN.fieldWorkCost.MAIZE;
	RN.fieldWorkCost.MAIZESLAGE				= RN.fieldWorkCost.MAIZESILAGE;
	RN.fieldWorkCost.MILLET					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.MUSTARD				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.OAT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.OILSEEDRADISH			= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.ONION					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.PEANUT					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.PEAS					= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.POPLAR					= 0;
	RN.fieldWorkCost.POPPY					= 0;
	RN.fieldWorkCost.POTATO					= RN.fieldWorkCost.POTATO;
	RN.fieldWorkCost.REDCABBAGE				= RN.fieldWorkCost.vegetable;
	RN.fieldWorkCost.RICE					= 0;
	RN.fieldWorkCost.RYE					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SORGHUM				= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SOYBEAN				= RN.fieldWorkCost.SOYBEAN;
	RN.fieldWorkCost.SPELT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.SUDANGRASS				= RN.fieldWorkCost.GRASS;
	RN.fieldWorkCost.SUGARBEET				= RN.fieldWorkCost.SUGARBEET;
	RN.fieldWorkCost.SUGARCANE				= RN.fieldWorkCost.SUGARCANE;
	RN.fieldWorkCost.SUNFLOWER				= RN.fieldWorkCost.SUNFLOWER;
	RN.fieldWorkCost.TOBACCO				= RN.fieldWorkCost.TOBACCO;
	RN.fieldWorkCost.TRITICALE				= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.WEED					= 0;
	RN.fieldWorkCost.WHEAT					= RN.fieldWorkCost.cereal;
	RN.fieldWorkCost.WHITECABBAGE			= RN.fieldWorkCost.vegetable;

	RN.cropEstabCostPerHA					= {};

	print("FS19_RealLifeNumbers: RealNumbersCropProductionCost active")


		print(" ")
		print("                              Gross     Supply     Net      Field     Field    Profit  Feed cost")
		print(currency.."/Ha                         income     costs     income     work      rent               "..currency.."/L")
		print(" ")

	RN.costTotalPerHa = {};
--	RN.netIncomePerHa = {};

	for i,fruitName in ipairs(RN.sortedFruits) do
--		if RN.fruits[fruitName] ~= nil then
			if fruitName ~= "WEED" then

				if RN.cropPricePerHa[fruitName] ~= nil then
					grossIncome = RN.cropPricePerHa[fruitName];
				else
					grossIncome = 0.0;
				end;
				if RN.fieldWorkCost[fruitName] ~= nil then
					fieldWork = RN.fieldWorkCost[fruitName];
				else
					fieldWork = 0.0;
				end;
				Rent = RN.rentPricePerHa;

				if RN.productCostPerHa[fruitName] ~= nil then
					productCostPerHa = RN.productCostPerHa[fruitName];
					netIncome = grossIncome - productCostPerHa;
					RN.netIncomePerHa[fruitName] = netIncome;
				else
					productCostPerHa = 0.0;
					netIncome = grossIncome - productCostPerHa;
				end;


				if RN.cropBonusYieldLitersPerHa[fruitName] ~= nil then
					if RN.cropBonusYieldLitersPerHa[fruitName] ~= 0 then
						RN.feedCostPerLiter[fruitName] = (fieldWork + RN.productCostPerHa[fruitName])/RN.cropBonusYieldLitersPerHa[fruitName];
						feedCostPerLiter = RN.feedCostPerLiter[fruitName];
					end;
				else
					feedCostPerLiter = 0.0000;
				end;

				local profit = netIncome - fieldWork - Rent;
				myPrintCropCost(fruitName, textWidth, currency.."/Ha", grossIncome, productCostPerHa, netIncome, fieldWork, Rent, profit, feedCostPerLiter);
			end;
--		end;
	end;
	print(" ")
end;

function RealNumbersCropProductionCost:keyEvent(unicode, sym, modifier, isDown)

	local textWidth = 18;
    local textWidth2 = 27;
	local textWidth3 = 40;
	local grossIncome  = 0;
	local netIncome  = 0;
	local fieldWork  = 0;
	local Fert  = 0;
	local Lime  = 0;
	local Seed  = 0;
	local Herbicide  = 0;
	local Rent  = 0;
	local profit = 0;
	local isDebug = RN.isDebug;
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

--	local savegameDirectory = g_currentMission.missionInfo.savegameDirectory;	-- works only after savegame is present and not in multiplayer

--	if savegameDirectory ~= nil then   -- will not work in multiplayer so commented out

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_y) then

		local hour = g_currentMission.environment.currentHour;
		local minute = g_currentMission.environment.currentMinute;
		local money = g_currentMission.missionInfo.money;
		local economicDifficulty = g_currentMission.missionInfo.economicDifficulty;
		local currentDay = g_currentMission.environment.currentDay;
		local currentMap = tostring(g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
		if isDebug then
			print("\nLeft Alt-ry pressed: RealNumbersCropProductionCost\n");
			if currentMap ~= nil then print("Map                   : "..currentMap); end;
			if money ~= nil then print("Money                 : "..money); end;
			if economicDifficulty ~=  nil then print("Economic difficulty   : "..economicDifficulty); end;
			print("Gamedays per year     : "..RN.gameDaysPerYear);
			if currentDay ~= nil then print("Current game day      : "..currentDay); end;
			if hour ~= nil or minute ~= nil then print("Time of day           : "..hour..":"..minute); end;
			print(" ");
		end;
--		if g_fruitTypeManager.fruitTypes ~= nil then
		if isDebug then print("\nCrop yield \n");end;
		for i,fruitName in ipairs(RN.sortedFruits) do
			myPrint(fruitName.." max yield",RN.cropBonusYieldLitersPerHa[fruitName],textWidth3," L/Ha");
		end;

		myPrint("Alfalfa silage max yield",RN.growth.alfalfaSilageNetVolumePerHa,textWidth," L/Ha");
		myPrint("Clover silage max yield",RN.growth.cloverSilageNetVolumePerHa,textWidth," L/Ha");
		myPrint("Grass silage max yield",RN.growth.grassSilageNetVolumePerHa,textWidth," L/Ha");

--		if isDebug then print("\nCrop income \n");end;
--		for i,fruitName in ipairs(RN.sortedFruits) do
--			myPrint(fruitName.." max income",RN.cropPricePerHa[fruitName],textWidth,currency.."/Ha");
--		end;


		print(" ")
		print("                              Gross     Supply     Net      Field     Field    Profit  Feed cost")
		print(currency.."/Ha                         income     costs     income     work      rent               "..currency.."/L")
		print(" ")

--		RN.costTotalPerHa = {};
--		RN.netIncomePerHa = {};

		for i,fruitName in ipairs(RN.sortedFruits) do

			if fruitName ~= "WEED" then
--				Income = RN.cropPricePerHa[fruitName];

				if RN.cropPricePerHa[fruitName] ~= nil then
					grossIncome = RN.cropPricePerHa[fruitName];
				else
					grossIncome = 0.0;
				end;
				if RN.fieldWorkCost[fruitName] ~= nil then
					fieldWork = RN.fieldWorkCost[fruitName];
				else
					fieldWork = 0.0;
				end;

				Rent = RN.rentPricePerHa;

				if RN.productCostPerHa[fruitName] ~= nil then
					productCostPerHa = RN.productCostPerHa[fruitName];
					netIncome = grossIncome - productCostPerHa;
					RN.netIncomePerHa[fruitName] = netIncome;
				else
					productCostPerHa = 0.0;
					netIncome = grossIncome - productCostPerHa;
				end;


				if RN.cropBonusYieldLitersPerHa[fruitName] ~= nil then
					if RN.cropBonusYieldLitersPerHa[fruitName] ~= 0 then
						RN.feedCostPerLiter[fruitName] = (fieldWork + RN.productCostPerHa[fruitName])/RN.cropBonusYieldLitersPerHa[fruitName];
						feedCostPerLiter = RN.feedCostPerLiter[fruitName];
					end;
				else
					feedCostPerLiter = 0.0000;
				end;

				local profit = netIncome - fieldWork - Rent;
				myPrintCropCost(fruitName, textWidth, currency.."/Ha", grossIncome, productCostPerHa, netIncome, fieldWork, Rent, profit, feedCostPerLiter);
			end;
		end;
		print(" ")

--				myPrint("Alfalfa silage max income",RN.forageCost.alfalfaSilageBaleIncomePerHa,textWidth3,currency.."/Ha");
--				myPrint("Clover silage max income",RN.forageCost.cloverSilageBaleIncomePerHa,textWidth3,currency.."/Ha");
--				myPrint("Grass silage max income",RN.forageCost.grassSilageBaleIncomePerHa,textWidth3,currency.."/Ha");

				if isDebug then print(" ");end;
				if currentDay ~= nil then print("Current game day      : "..currentDay); end;
				print("Gamedays per year     : "..RN.gameDaysPerYear);
				if isDebug then print(" ");end;
--			end;
	end;
--	else
--		if not RN.multiPlayer then print("No save game yet. Save the game, quit and reload"); end;
--	end;
end;
function RealNumbersCropProductionCost:update(dt)
end;
function RealNumbersCropProductionCost:draw()
end;
function RealNumbersCropProductionCost:deleteMap()
end;
function RealNumbersCropProductionCost:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersCropProductionCost);
